@@ -1,9 +1,9 @@
-# $Id: Composers.pm 2238 2007-03-24 06:04:33Z comdog $
+# $Id: Composers.pm 2243 2007-03-26 06:55:17Z comdog $
 package Brick::Composers;
 use base qw(Exporter);
 use vars qw($VERSION);
 
-$VERSION = sprintf "1.%04d", q$Revision: 2238 $ =~ m/ (\d+) /xg;
+$VERSION = sprintf "1.%04d", q$Revision: 2243 $ =~ m/ (\d+) /xg;
 
 use Brick::Bucket;
 
@@ -36,6 +36,8 @@ in programming rather than a failure of the data to validate.
 
 =over 4
 
+=item __and( LIST OF CODEREFS )
+
 =item __compose_satisfy_all( LIST OF CODEREFS )
 
 This is AND with NO short-circuiting.
@@ -55,6 +57,12 @@ sub __compose_satisfy_all
 	$bucket->__compose_satisfy_N( scalar @_, @_ );
 	}
 
+BEGIN {
+*__and = *__compose_satisfy_all;
+}
+
+=item __or( LIST OF CODEREFS )
+
 =item __compose_satisfy_any( LIST OF CODEREFS )
 
 This is OR but with NO short-circuiting.
@@ -73,6 +81,12 @@ sub __compose_satisfy_any
 	$bucket->__compose_satisfy_N_to_M( 1, scalar @_, @_ );
 	}
 
+BEGIN {
+*__or = *__compose_satisfy_any;
+}
+
+=item __none( LIST OF CODEREFS )
+
 =item __compose_satisfy_none( LIST OF CODEREFS )
 
 
@@ -92,6 +106,10 @@ sub __compose_satisfy_none
 	$bucket->__compose_satisfy_N_to_M( 0, 0, @_ );
 	}
 
+BEGIN {
+*__none = *__compose_satisfy_none;
+}
+
 =item __compose_satisfy_N( SCALAR, LIST OF CODEREFS )
 
 This function creates a new constraint that returns true if exactly N
@@ -138,7 +156,7 @@ sub __compose_satisfy_N_to_M
 			my @dies = ();
 			foreach my $sub ( @subs )
 				{
-				eval { $sub->( @_ ) };
+				my $result = eval { $sub->( @_ ) };
 				my $at = $@;
 				$count++ unless $at;
 				#print STDERR "\n!!!!Sub died!!!!\n" if ref $at;
@@ -148,12 +166,14 @@ sub __compose_satisfy_N_to_M
 				};
 
 			my $range = $n == $m ? "exactly $n" : "between $n and $m";
-
+			
 			die {
 				message => "Satisfied $count of $max sub-conditions, needed to satisfy $range",
 				handler => $caller[0]{'sub'},
 				errors  => \@dies,
 				} unless $n <= $count and $count <= $m;
+				
+			return 1;
 			},
 		});
 
@@ -162,6 +182,8 @@ sub __compose_satisfy_N_to_M
 	return $sub;
 	}
 
+=item __not( CODEREF )
+
 =item __compose_not( CODEREF )
  
 This composers negates the sense of the code ref. If the code ref returns
@@ -169,6 +191,7 @@ true, this composer makes it false, and vice versa.
 
 =cut
 
+
 sub __compose_not
 	{
 	my( $bucket, $not_sub ) = @_;
